#ifndef NT2_INCLUDE_FUNCTIONS_PCHIP_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_PCHIP_HPP_INCLUDED

#include <nt2/interpol/include/functions/pchip.hpp>

#endif
